@@ -94,11 +94,13 @@ def get_nis_name(original_name):
     :param original_name:
     :return:
     """
+    if original_name.strip() == "":
+        return ""
+    else:
+        prefix = original_name[0] if original_name[0].isalpha() else "_"
+        remainder = original_name[1:] if original_name[0].isalpha() else original_name
 
-    prefix = original_name[0] if original_name[0].isalpha() else "_"
-    remainder = original_name[1:] if original_name[0].isalpha() else original_name
-
-    return prefix + re.sub("[^0-9a-zA-Z_]", "_", remainder)
+        return prefix + re.sub("[^0-9a-zA-Z_]", "_", remainder)
 
 
 def call_udif_function(function_name, state: State = None):
@@ -119,7 +121,7 @@ lcia_method_names = {}
 
 
 def lcia_method(indicator: str, method: str = None, horizon: str = None, compartment: str = None,
-                subcompartment: str = None,
+                subcompartment: str = None, category: str = None,
                 state: State = None, lcia_methods: PartialRetrievalDictionary = None):
     """
 
@@ -130,7 +132,7 @@ def lcia_method(indicator: str, method: str = None, horizon: str = None, compart
     :param subcompartment: Subcompartment to which the indicator applies
     :param state: Current values of processor plus parameters
     :param lcia_methods: Where LCIA data is collected
-    :return: A dictionary with the
+    :return: A dictionary with the indicators and calculated values
     """
     global lcia_method_names
     if indicator is None or indicator.strip() == "":
@@ -150,6 +152,8 @@ def lcia_method(indicator: str, method: str = None, horizon: str = None, compart
         k["c"] = compartment
     if subcompartment:
         k["s"] = subcompartment
+    if category:
+        k["t"] = category
 
     ms = lcia_methods.get(key=k, key_and_value=True)
     indices = create_dictionary()
@@ -172,6 +176,9 @@ def lcia_method(indicator: str, method: str = None, horizon: str = None, compart
             idx_name += f'_{get_nis_name(k["c"])}'
         if k["s"] != "":
             idx_name += f'_{get_nis_name(k["s"])}'
+        if k["t"] != "":
+            idx_name += f'_{get_nis_name(k["t"])}'
+
         if idx_name in indices:
             lst = indices[idx_name]
         else:
