@@ -526,7 +526,7 @@ class PartialRetrievalDictionary:
         # Counter
         self._id_counter = 0
 
-    def get(self, key, key_and_value=False, full_key=False, just_oid=False):
+    def get(self, key, key_and_value=False, full_key=False, just_oid=False, just_key=False):
         """
         Retrieve one or more objects matching "key"
         If "key_and_value" is True, return not only the value, also matching key (useful for multiple matching keys)
@@ -541,11 +541,22 @@ class PartialRetrievalDictionary:
             if case_sensitive:
                 key2 = {k.lower(): v for k, v in key.items()}
             else:
-                key2 = {k.lower(): v if k.startswith("__") else v.lower() for k, v in key.items()}
+                key2 = {k.lower(): v if k.startswith("__") else v.lower() if v else None for k, v in key.items()}
         else:
             key2 = key
 
-        sets = [self._keys.get(k, {}).get(v, set()) for k, v in key2.items()]
+        # sets = []
+        # for k, v in key2.items():
+        #     if v is not None:
+        #         sets.append(self._keys.get(k, {}).get(v, set()))
+        #     else:
+        #         _ = set().union(*self._keys.get(k, {}).values())
+        #         sets.append(_)
+
+        sets = [self._keys.get(k, {}).get(v, set())
+                if v is not None else
+                set().union(*self._keys.get(k, {}).values())
+                for k, v in key2.items()]
 
         # Find shorter set and Remove it from the list
         min_len = 1e30
@@ -564,10 +575,13 @@ class PartialRetrievalDictionary:
         # Obtain list of results
         if full_key and len(result) > 1:
             raise Exception("Zero or one results were expected. "+str(len(result)+" obtained."))
-        if not key_and_value:
-            return [self._objs[oid][1] for oid in result]
+        if not just_key:
+            if not key_and_value:
+                return [self._objs[oid][1] for oid in result]
+            else:
+                return [self._objs[oid] for oid in result]
         else:
-            return [self._objs[oid] for oid in result]
+            return [self._objs[oid][0] for oid in result]
 
     def get_one(self, key, key_and_value=False, full_key=False, just_oid=False):
         results = self.get(key, key_and_value, full_key, just_oid)
